Exec {
  path => '/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin'
}

hiera_include('default')

# PARAMS
# ======
$ha_servers = {
        priority_hostname => 'ocp-tb-1',
        priority_ip => '192.168.0.18',
        hostnames => ['ocp-tb-2', 'ocp-tb-3'],
        ips => ['192.168.0.19', '192.168.0.20'],
      }
$mysql_users = {
                'keystone@192.168.0.2*' => {
                        password_hash => mysql_password('keystone'),
                },
                'glance@192.168.0.2*' => {
                        password_hash => mysql_password('glance'),
                },
                'nova@192.168.0.2*' => {
                        password_hash => mysql_password('nova'),
                },
                'cinder@192.168.0.2*' => {
                        password_hash => mysql_password('cinder'),
                },
                'neutron@192.168.0.2*' => {
                        password_hash => mysql_password('neutron'),
                },
        }
$mysql_databases =  {
                'keystone' => {},
                'glance' => {},
                'nova' => {},
                'cinder' => {},
                'neutron' => {},
        }
$mysql_grants = {
                'keystone@192.168.0.2*/*.*' => {
                        user => 'keystone@192.168.0.2*',
                },
                'glance@192.168.0.2*/*.*' => {
                        user => 'glance@192.168.0.2*',
                },
                'nova@192.168.0.2*/*.*' => {
                        user => 'nova@192.168.0.2*',
                },
                'cinder@192.168.0.2*/*.*' => {
                        user => 'cinder@192.168.0.2*',
                },
                'neutron@192.168.0.2*/*.*' => {
                        user => 'neutron@192.168.0.2*',
                },
        }

# NODE DEFINITION
# ===============

## RHMK NODES

node 'ocp-tb-1.openstacklocal' {
  class {'iaas::role::rhmk':
#       percona_master => true,
       keepalived_state => 'MASTER',
       keepalived_priority => 102,
       ha_servers => $ha_servers,
       mysql_users => $mysql_users,
       mysql_databases => $mysql_databases,
       mysql_grants => $mysql_grants,
  }
}

node 'ocp-tb-2.openstacklocal' {
 class {'iaas::role::rhmk':
       keepalived_state => 'BACKUP',
       keepalived_priority => 101,
       ha_servers => $ha_servers,
       mysql_users => $mysql_users,
       mysql_databases => $mysql_databases,
       mysql_grants => $mysql_grants,
 }
}

node 'ocp-tb-3.openstacklocal' {
 class {'iaas::role::rhmk':
       keepalived_state => 'BACKUP',
       keepalived_priority => 100,
       ha_servers => $ha_servers,
       mysql_users => $mysql_users,
       mysql_databases => $mysql_databases,
       mysql_grants => $mysql_grants,
 }
}

## CEPH STORAGE NODES

node '<storage_hostname>' {

 include 'iaas::role::storage'

 ceph::osd {
      '/dev/vdb':
        journal => '/osd1';

      '/dev/vdc':
        journal => '/osd2',
 }
 
 ceph::key {
  'client.admin':
    secret => 'AQDgL/hUSC2kLBAAnWJaSiqJG+YMk+XV9sapnw==',
    cap_mon => 'allow *',
    cap_osd => 'allow *',
    cap_mds => 'allow',
    inject => 'true',
    inject_as_id => 'mon.',
    inject_keyring => '/var/lib/ceph/mon/ceph-ocp-ubuntu20/keyring';

  'client.bootstrap-osd':
    secret => 'AQDlL/hUUCpdFBAAZeo6mKj4yeKPmVKfUY5awA==',
    cap_mon => 'allow profile bootstrap-osd',
    keyring_path => '/var/lib/ceph/bootstrap-osd/ceph.keyring',
    inject => 'true',
    inject_as_id => 'mon.',
    inject_keyring => '/var/lib/ceph/mon/ceph-ocp-ubuntu20/keyring';

  'client.glance':
    secret => 'AQBgGdJUCPwjLRAARZ0KEaxewYcYHT3j5Gl5Cg==',
    cap_mon => 'allow r',
    cap_osd => 'allow class-read object_prefix rbd_children, allow rwx pool=images',
    inject => 'true',
    inject_as_id => 'mon.',
    inject_keyring => '/var/lib/ceph/mon/ceph-ocp-ubuntu20/keyring';

  'client.cinder':
    secret => 'AQAvxQpVKJ03KxAADFv78tedrAWZx1SoRdsQUA==',
    cap_mon => 'allow r',
    cap_osd => 'allow class-read object_prefix rbd_children, allow rwx pool=volumes, allow rwx pool=vms, allow rx pool=images',
    inject => 'true',
    inject_as_id => 'mon.',
    inject_keyring => '/var/lib/ceph/mon/ceph-ocp-ubuntu20/keyring';

  'client.cinder-backup':
    secret => 'AQBKvuVUMHvaGhAADT6nvBv9LFs7dqpB8Kis0Q==',
    cap_mon => 'allow r',
    cap_osd => 'allow class-read object_prefix rbd_children, allow rwx pool=backups',
    inject => 'true',
    inject_as_id => 'mon.',
    inject_keyring => '/var/lib/ceph/mon/ceph-ocp-ubuntu20/keyring',
 }

 ceph::pool { 'images':
                 pg_num => 128;
               'volumes':
                 pg_num => 128;
               'vms':
                 pg_num => 128;
               'backups':
                 pg_num => 128,
 }

$ceph_key_repo = "-----BEGIN PGP PUBLIC KEY BLOCK-----
Version: GnuPG v1.4.11 (GNU/Linux)

mQINBE+5bugBEADP31ZaQNvhOOQxjDwL/VYDLhtaGq4Q74FCY23uSQAMboKwo4JB
Te2JTSwBwU/RAPuWTrlKaQBPS30VF5SJN9t16llmoBWqhtBVf/lhQonC/28dTB6D
KR7Ahiz4Nv2g9m1sLau86JblQuODo8vWHXxahYSLQSyyxIXnlE4K3c1k0S4feLqu
ZxFtc2cFrQ/bUX9zXg6PXjDVAfY2R+x1JKGkVO/iwP+cjS1tCbvzdKcnQJEXpBwd
yHvDBuF3IjuR9JgrBhb1ALqexhFKHzG1kHFfOZ3DLVohig68lfyjCepGgo0BPOyy
S3Yk0QMumEaj9zRJurg49zWemX05XiBGt8SeCFxNUjXGYDIzSQ30K8fXmyjB74CW
EUDUuTpTt7oZF9jKCjfKmQwvW4GgJ4J0FSwiorXPK27didjLJCnkTt43v0ZETMRW
aADtiKFHl7lICuRmeXbd+6VkVqmoOz7ialMHnZ2KrHlqTcTPMd4llC4ayi2qS6Qb
dIi1g9fa5YMS6I7yGxmW4AWwNy7SE8DsTja0aGFR9k432r+Vxtr52jrmP2vVexva
CVaQkdk2/KEY3MjCPngiZwoTcOONYvNMvQaPrUtRuatcWJOgWsQVedY/UBxk968n
JzfnNDngbcYDRnOD8wLWyBGyYbOdg1ucckLXFEtPVXoRER5JHMcYhyh+/QARAQAB
tCRDZXBoIFJlbGVhc2UgS2V5IDxzYWdlQG5ld2RyZWFtLm5ldD6JAjgEEwECACIF
Ak+5bugCGwMGCwkIBwMCBhUIAgkKCwQWAgMBAh4BAheAAAoJEH6/3V0X7TFtSjEP
/A2pazEPwXrlQAHAjcXaFcPguKnXFrXRfbLpM9aZPR5gxH8mWl9RhEW/nL5pBf6A
Tx7lQ4F/h9bDlf4/bejuxUflkrJEPVWkyPf3hvImjSBs+LBTk4OkpUJwYd9AynsG
551Q0+6qxFfRVLCR6rLPHbMquXsKHROsSumEGUNrsMVC87gvtXEe/AOLUuRLEbjU
QqGKP2+mvliizU844a11B/bXViXhkNZw66ESAuqOw0dVPTo6aPLhuSDDrGEHQNTz
BsUseiUq795DqTE/5sL3lbTPrT1hKoIJFixYvaYBdygDgovsAi33nPn8UPitS5aD
zGJ/ByDdnI4QW15NN1diMp+BuvOCWLpMaxVQNflARlxxtfIfnvaKjgccr1YOyT91
5tlbdr0y05r1uYZjYU5/4llilypUgzzQB1jeetr06fOpVvswAAWQJiS5JJU+V84W
r4sIBhZzGw1uvqNxIBWtk85W1ya7CmisRO7PZYW5lsLxZ48BxZhr45ar6/iDYreT
OOeP1f9GoJW0X+FAocNc/pobY02MhB/BXV1LRM3lY+yOK3sskspnMihMqP7tSfop
iJRtfXMLNdRRJFVZ5VSr1MCDK5RPQaqVsuvdtVqOJr1RwAQPjjzisOh+NYmvabkd
cVxjSV5DX0fMODr2l7cAXxJjZsAs6AlnQOGPg/NXKdkZiEYEEBECAAYFAk+5cEAA
CgkQ2kQg7SiJlcjJIACgsGpIw9ShLBciO3Y349ja7ILjC8cAnRrqoIpFxUrSIJF/
8+w98auNwA18
=uX7x
-----END PGP PUBLIC KEY BLOCK-----
"

 file { '/root/ceph_repo_key':
    content => $ceph_key_repo,
 }

 File['/root/ceph_repo_key'] -> Apt::Key['ceph']
  
}
